Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Message2IP ¶
Message2IP converts a given message to IP
Types ¶
type Message ¶
type Message struct {
CID string `json:"cid"`
Payload interface{} `json:"payload"`
}
Message encapsulates connection ID it received from or to be sent to and a payload received from or should be sent to Websocket connection.
func IP2Message ¶
IP2Message converts a given IP to message structure
Click to show internal directories.
Click to hide internal directories.